%/* Copyright (c) 2017 Suzuki Lab */ 
% --------------------------------------------------------------------------------------------------
% Apply LDA to find model parameters
% --------------------------------------------------------------------------------------------------

% Calculate sample mean vectors for the two classes
m1 = mean(x1)';  
m2 = mean(x2)';   

% Form scatter matrices for two classes
n1 = size(x1,1);    %determine number of data examples n1
n2 = size(x2,1);    %determine number of data examples n2
S1 = n1 * cov(x1);
S2 = n2 * cov(x2);

%Compute between- and within-class scatter matrices
SB = (m1-m2)*(m1-m2)';
SW = S1 + S2;

%Solve Fisher eigenvector equation, and display results
[w_all,J] = eigsort(SW\SB);
string = sprintf('Best Fisher ratio is %06.4f', J(1));
disp(string)

% Name the best eigenvector as w, and display it
w = w_all(:,1);

% calculate the intercept with a simple method
c = (1/2)*w'*(m1+m2);

% --------------------------------------------------------------------------------------------------
% Draw the decision boundry found by LDA
% --------------------------------------------------------------------------------------------------

% draw the w vector direction as an arrow 
w_scale = 1;
quiver(0, 0, w_scale*w(1), w_scale*w(8), 'k', 'linewidth', 3)
t = text(w_scale*w(1), w_scale*w(8), 'LDA W vector');
set(t, 'fontname','times', 'FontSize', 14, 'FontWeight', 'bold', 'color', [0,0,0])

% draw the decision boundry
% note the equation w1*x1 + w2*x2 - c = 0 can be converted to x2 = -(w1/w2)*x1 + c/w2
a = linspace(fig_x_start, fig_x_end, 1000);
b = -(w(1)/w(8))*a + c/w(8);
plot(a, b, 'k', 'linewidth', 3)
t = text(0.8, 0, 'LDA decision boundry');
set(t, 'fontname','times', 'FontSize', 14, 'FontWeight', 'bold', 'color', [0,0,0])
