% --------------------------------------------------------------------------------------------------
% Draw the class-wise sample projections found by PCA
% --------------------------------------------------------------------------------------------------

% the direction of w can be safely flipped (for simplicity of the rest of
% program). The only difference it makes is that it flips the decision
% (positive to negative and wise versa)
w = -w;

% Form inner product of w with all data vector examples in x1 and x2
y1 = w' * x1';
y2 = w' * x2';

% Find range and define bins for histograms
minhist = round(1.5*min([y1,y2]));
maxhist = round(1.5*max([y1,y2]));
bins = minhist:.1:maxhist;

% Make the histograms
hist1 = hist(y1,bins);
hist2 = hist(y2,bins);

% Normalize both histograms so that they are PDFs
PDF1 = hist1 / sum(hist1);
PDF2 = hist2 / sum(hist2);

% Plot the histograms
figure(8); 
subplot(1,2,2);
set(gca,'fontname','times') 
area(bins,PDF1,'FaceColor', 'r');
hold on;
area(bins,PDF2,'FaceColor', 'b');
xlim([-1,1])
title({'Normalized histograms of sample','projections onto W for PCA'}, 'FontSize', 14); 
h = legend('Class 1', 'Class 2');
set(h, 'FontSize', 16, 'fontname', 'times');
hold off;