%/* Copyright (c) 2017 Suzuki Lab */ 
% --------------------------------------------------------------------------------------------------
% Apply PCA to find model parameters
% --------------------------------------------------------------------------------------------------

% concatenate the two classes
allData = [x1; x2];
w_all = quickPCA(allData);

% the best principle component corresponding to highest eigenvalue
w = w_all(:,1);

% calculate the intercept with a simple method
c = (1/2)*w'*(m1+m2);

% we might manually change the intecept for better visualization of the
% decision boundry
c = 0.05;

% --------------------------------------------------------------------------------------------------
% Draw the decision boundry found by PCA
% --------------------------------------------------------------------------------------------------

% draw the w vector direction as an arrow 
figure(7)
w_scale = 5;
quiver(0, 0, w_scale*w(1), w_scale*w(8), 'color', [1,.5,0], 'linewidth', 3)
t = text(w_scale*w(1), w_scale*w(8), 'PCA W vector');
set(t, 'fontname','times', 'FontSize', 14, 'FontWeight', 'bold', 'color', [1,.5,0])

% draw the decision boundry
% note the equation w1*x1 + w2*x2 - c = 0 can be converted to x2 = -(w1/w2)*x1 + c/w2
a = linspace(fig_x_start, fig_x_end, 1000);
b = -(w(1)/w(8))*a + c/w(8);
plot(a, b, 'color', [1,.5,0], 'linewidth', 3)
t = text(1.3, 0.4, 'PCA decision boundry');
set(t, 'fontname','times', 'FontSize', 14, 'FontWeight', 'bold', 'color', [1,.5,0])