%/* Copyright (c) 2017 Suzuki Lab */ 

% --------------------------------------------------------------------------------------------------
% Apply PCA to find model parameters
% --------------------------------------------------------------------------------------------------

% concatenate the two classes
allData = [x1; x2];
w_all = quickPCA(allData)

% the best principle component corresponding to highest eigenvalue
w = w_all(:,1)

% the direction of w can be safely flipped (for simplicity of the rest of
% program). The only difference it makes is that it flips the decision
% (positive to negative and wise versa)
w = -w;


% calculate the intercept with a simple method
c = (1/2)*w'*(m1+m2)

% --------------------------------------------------------------------------------------------------
% Draw the decision boundry found by PCA
% --------------------------------------------------------------------------------------------------

% draw the w vector direction as an arrow 
figure(3)
w_scale = 5;
quiver(0, 0, w_scale*w(1), w_scale*w(2), 'color', [1,.5,0], 'linewidth', 3)
t = text(w_scale*w(1), w_scale*w(2), 'PCA W vector');
set(t, 'fontname','times', 'FontSize', 14, 'FontWeight', 'bold', 'color', [1,.5,0])

% draw the decision boundry
% note the equation w1*x1 + w2*x2 - c = 0 can be converted to x2 = -(w1/w2)*x1 + c/w2
a = linspace(fig_x_start, fig_x_end, 1000);
b = -(w(1)/w(2))*a + c/w(2);
plot(a, b, 'color', [1,.5,0], 'linewidth', 3)
t = text(-6, 4, 'PCA decision boundry');
set(t, 'fontname','times', 'FontSize', 14, 'FontWeight', 'bold', 'color', [1,.5,0])



% --------------------------------------------------------------------------------------------------
% Draw the class-wise sample projections found by PCA
% --------------------------------------------------------------------------------------------------

% Form inner product of w with all data vector examples in x1 and x2
y1 = w' * x1';
y2 = w' * x2';

% Find range and define bins for histograms
minhist = round(1.5*min([y1,y2]));
maxhist = round(1.5*max([y1,y2]));
bins = minhist:.1:maxhist;

% Make the histograms
hist1 = hist(y1,bins);
hist2 = hist(y2,bins);

% Plot the histograms
figure(4); 
subplot(1,2,2);
set(gca,'fontname','times') 
area(bins,hist1,'FaceColor', 'r');
hold on;
area(bins,hist2,'FaceColor', 'b');
xlim([-10,10])
title({'Histograms of sample projections','onto W for PCA'}, 'FontSize', 14); 
h = legend('Class 1', 'Class 2');
set(h, 'FontSize', 16, 'fontname', 'times');
hold off;


% --------------------------------------------------------------------------------------------------
% Calculate and draw the ROC for PCA + Calculate AUC
% --------------------------------------------------------------------------------------------------

% determine number of bins in histograms
Nbins = size(hist1,2);  

% Normalize both histograms so that they are PDFs
PDF1 = hist1 / sum(hist1);
PDF2 = hist2 / sum(hist2);

% Initialize PD (probability of detection) and PFA (probability of false alarm) at (1,1)
PD = [];
PFA = [];
PD(1)=1;
PFA(1)=1;

% Move to the right along the histograms, subtracting areas as you go
for i=2:Nbins, 
    PFA(i)=PFA(i-1)-PDF1(i);
	PD(i)=PD(i-1)-PDF2(i);
end;

% Plot ROC curve
figure(5);
hold
plot(PFA, PD, 'color', [1,.5,0],'LineWidth',2);
title('ROC curves for LDA and PCA models')

% Compute area under the ROC curve (AUC) - Az
Az = 0;
for i=2:Nbins,
    Az = Az + PD(i) * (PFA(i-1)-PFA(i));
end;
Az

pca_text = sprintf('PCA with AUC of %05.3f', Az);
h = legend(lda_text, pca_text, 'Location', 'southeast');
set(h, 'FontSize', 16, 'fontname', 'times');