function [coeff, score] = quickPCA(X)
%/* Copyright (c) 2017 Suzuki Lab */ 
% PCA Principal Component Analysis (PCA) on raw data.
% [coeff, score] = quickPCA(x) returns the principle components in a
% descending order based on the scores (eigenvalues).
% X is a nxp matrix where n is the number of observations and p is the
% number of features.

% subtract the mean from data
mu = mean(X);
Xm = bsxfun(@minus, X, mu);

% calculate the covariance of zero mean data
C = cov(Xm);

% calculate the principle components and corresponding eigenvalues
[V,D] = eig(C);

% sort eigenvectors desc
[D, i] = sort(diag(D), 'descend');
V = V(:,i);

% return the output values
coeff = V;
score = D;
