function quickPlotMatrix(x, y, color, marker, s, varNames)
%/* Copyright (c) 2017 Suzuki Lab */ 
% plot a Trellis plot for data x groupped by y.
% quickPlotMatrix(x, y, color, marker, size, varNames) is the
% main function to plot. x is pxn data where p is number of features and n
% is number of observations. x is groupped by y, i.e., y is 1xn matrix
% where its element can be 1 or 2, indicating group 1 or 2. color, marker,
% and s are 1x2 vectors indicating color, marker, and the marker size
% for group 1 and 2, correspondingly. varNames contains the name of p 
% features.


% extracting group 1 and 2 data
p = size(x,1);
x1 = x(:,y==1);
x2 = x(:,y==2);


for row=1:p
    for col=1:p
        
        % start a subplot
        subplot(p, p, (row-1)*p + col);
        
        % if 1 dimension only, plot the normalized histogram
        if row==col;
            y1 = x1(row,:);
            y2 = x2(row,:);
            % Find range and define bins for histograms
            minhist = round(1.5*min([y1,y2]));
            maxhist = round(1.5*max([y1,y2]));
            bins = minhist:.1:maxhist;

            % Make the histograms
            hist1 = hist(y1,bins);
            hist2 = hist(y2,bins);

            % Normalize both histograms so that they are PDFs
            PDF1 = hist1 / sum(hist1);
            PDF2 = hist2 / sum(hist2);
            
            % Plot the histograms
            plot(bins,PDF1,'color', color(1));
            hold on;
            plot(bins,PDF2,'color', color(2));
            hold off;
            
            % modify the plot
            axis square;
            set(gca,'fontname','times')
            xlabel(varNames(col,:), 'FontSize', 10);

        % plot one feature versus another
        else
            plot(x1(col,:), x1(row,:), strcat(color(1),marker(1)), 'markers', s(1))
            hold on
            plot(x2(col,:), x2(row,:), strcat(color(2),marker(2)), 'markers', s(2))
            hold off
            
            % modify the plot
            axis square;
            set(gca,'fontname','times')
            xlabel(varNames(col,:), 'FontSize', 10);
            ylabel(varNames(row,:), 'FontSize', 10);
        end
        
        % legends
%         h = legend('Class 1', 'Class 2', 'location','NorthEast');
%         set(h, 'FontSize', 8, 'fontname', 'times');
        
    end
end
